"use strict";
const omit = require("lodash/omit.js");
const mapValues = require("lodash/mapValues.js");
const styles_lib_css_breakpoints_cjs = require("./breakpoints.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const omit__default = /* @__PURE__ */ _interopDefaultCompat(omit);
const mapValues__default = /* @__PURE__ */ _interopDefaultCompat(mapValues);
const breakpointQuery = mapValues__default.default(
  omit__default.default(styles_lib_css_breakpoints_cjs.breakpoints, "mobile"),
  (bp) => `screen and (min-width: ${bp}px)`
);
const makeMediaQuery = (breakpoint) => (styles) => !styles || Object.keys(styles).length === 0 ? {} : {
  [breakpointQuery[breakpoint]]: styles
};
const mediaQuery = {
  tablet: makeMediaQuery("tablet"),
  desktop: makeMediaQuery("desktop"),
  wide: makeMediaQuery("wide")
};
const responsiveStyle = ({
  mobile,
  tablet,
  desktop,
  wide
}) => ({
  ...omit__default.default(mobile, "@media"),
  ...tablet || desktop || wide ? {
    "@media": {
      ...mediaQuery.tablet(tablet ?? {}),
      ...mediaQuery.desktop(desktop ?? {}),
      ...mediaQuery.wide(wide ?? {})
    }
  } : {}
});
exports.breakpointQuery = breakpointQuery;
exports.responsiveStyle = responsiveStyle;
