import omit from "lodash/omit.js";
import mapValues from "lodash/mapValues.js";
import { breakpoints } from "./breakpoints.mjs";
const breakpointQuery = mapValues(
  omit(breakpoints, "mobile"),
  (bp) => `screen and (min-width: ${bp}px)`
);
const makeMediaQuery = (breakpoint) => (styles) => !styles || Object.keys(styles).length === 0 ? {} : {
  [breakpointQuery[breakpoint]]: styles
};
const mediaQuery = {
  tablet: makeMediaQuery("tablet"),
  desktop: makeMediaQuery("desktop"),
  wide: makeMediaQuery("wide")
};
const responsiveStyle = ({
  mobile,
  tablet,
  desktop,
  wide
}) => ({
  ...omit(mobile, "@media"),
  ...tablet || desktop || wide ? {
    "@media": {
      ...mediaQuery.tablet(tablet ?? {}),
      ...mediaQuery.desktop(desktop ?? {}),
      ...mediaQuery.wide(wide ?? {})
    }
  } : {}
});
export {
  breakpointQuery,
  responsiveStyle
};
